# Generated by Django 4.0.7 on 2022-11-06 16:52

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="General",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
            ],
            options={
                "permissions": (
                    ("basic_access", "Can access this app"),
                    ("admin_access", "Can set taxes and view everything"),
                ),
                "managed": False,
                "default_permissions": (),
            },
        ),
    ]
